@@ -268,7 +268,7 @@ void notify_call(gn_call_status call_status, gn_call_info *call_info, struct gn_
 	*/
 }
 
-void on_menu_getCalls(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
+gboolean getCalls(GtkWidget *topLevel, UIComponents *uic) {
 	gn_data		data;
 	gn_error	error = GN_ERR_NONE;
 	
@@ -286,90 +286,120 @@ void on_menu_getCalls(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
 			error = gn_sm_functions(GN_OP_SetCallNotification, &data, state);
 		}
 		if (error != GN_ERR_NONE) {
-			hildon_banner_show_informationf(GTK_WIDGET(gtk_widget_get_toplevel(GTK_WIDGET(checkMenuitem))), GTK_STOCK_DIALOG_INFO, _("This driver doesn't support call signaling.\n(%s)"), gn_error_print(error));
+			hildon_banner_show_informationf(topLevel, GTK_STOCK_DIALOG_INFO, _("This driver doesn't support call signaling.\n(%s)"), gn_error_print(error));
 			uic->getCalls = !(uic->getCalls);
-			gtk_check_menu_item_set_active(checkMenuitem, uic->getCalls);
 			if (uic->phoneOpened) {
 				uic->phoneOpened = !(uic->phoneOpened);
 				gn_lib_phone_close(state);
 			}
+			return FALSE;
+		} else {
+			hildon_banner_show_informationf(topLevel, GTK_STOCK_DIALOG_INFO, _("Waiting for a call ..."));
 		}
 	} else {
-		if (uic->phoneOpened) {
+		hildon_banner_show_informationf(topLevel, GTK_STOCK_DIALOG_INFO, _("Stopped waiting for a call ..."));
+		gn_data_clear(&data);
+		data.call_notification = NULL;
+		gn_sm_functions(GN_OP_SetCallNotification, &data, state);
+		if (uic->phoneOpened && !uic->getSms) {
 			uic->phoneOpened = !(uic->phoneOpened);
 			gn_lib_phone_close(state);
 		}
 	}
+	return TRUE;
 }
 
-void on_menu_getSms(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
+void on_menu_getCalls(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
+	if (getCalls(GTK_WIDGET(gtk_widget_get_toplevel(GTK_WIDGET(checkMenuitem))), uic) == FALSE) {
+		gtk_check_menu_item_set_active(checkMenuitem, FALSE);
+	}
+}
+
+gboolean getSms(GtkWidget *topLevel, UIComponents *uic) {
 	gn_data		data;
 	gn_error	error = GN_ERR_NONE;
 	
 	uic->getSms = !(uic->getSms);
 	if (uic->getSms) {
-		/* Set up so that we get notified of incoming sms, if supported by the driver */
-		gn_data_clear(&data);
-		data.on_sms = notify_sms;
-		data.callback_data = uic;
-		error = gn_sm_functions(GN_OP_OnSMS, &data, state);
-		if (error != GN_ERR_NONE) {
-			hildon_banner_show_informationf(GTK_WIDGET(gtk_widget_get_toplevel(GTK_WIDGET(checkMenuitem))), GTK_STOCK_DIALOG_INFO, _("This driver doesn't support sms signaling.\n(%s)"), gn_error_print(error));
-			uic->getSms = !(uic->getSms);
-			gtk_check_menu_item_set_active(checkMenuitem, uic->getSms);
+		if (!uic->phoneOpened) {
+			error = gn_lib_phone_open(state);
 		}
+		/* Set up so that we get notified of incoming sms, if supported by the driver */
+		if (error == GN_ERR_NONE) {
+			gn_data_clear(&data);
+			data.on_sms = notify_sms;
+			data.callback_data = uic;
+			error = gn_sm_functions(GN_OP_OnSMS, &data, state);
+		}
+		if (error != GN_ERR_NONE) {
+			hildon_banner_show_informationf(topLevel, GTK_STOCK_DIALOG_INFO, _("This driver doesn't support sms signaling.\n(%s)"), gn_error_print(error));
+			uic->getSms = !(uic->getSms);
+			if (uic->phoneOpened) {
+				uic->phoneOpened = !(uic->phoneOpened);
+				gn_lib_phone_close(state);
+			}
+			return FALSE;
+		} else {
+			hildon_banner_show_informationf(topLevel, GTK_STOCK_DIALOG_INFO, _("Waiting for SMS ..."));
+		}
+	} else {
+		hildon_banner_show_informationf(topLevel, GTK_STOCK_DIALOG_INFO, _("Stopped waiting for SMS ..."));
+		gn_data_clear(&data);
+		data.on_sms = NULL;
+		gn_sm_functions(GN_OP_OnSMS, &data, state);
+		if (uic->phoneOpened && !uic->getCalls) {
+			uic->phoneOpened = !(uic->phoneOpened);
+			gn_lib_phone_close(state);
+		}
+	}
+	return TRUE;
+}
+
+void on_menu_getSms(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
+	if (getSms(GTK_WIDGET(gtk_widget_get_toplevel(GTK_WIDGET(checkMenuitem))), uic) == FALSE) {
+		gtk_check_menu_item_set_active(checkMenuitem, FALSE);
 	}
 }
 
 GtkMenu *create_menus(UIComponents *uic) {
 	GtkWidget *menuBar;
-	GtkWidget *menuGroup;
 	GtkWidget *menuItem;
 	GtkWidget *image;
 	
 	menuBar = gtk_menu_new ();
 	
-	menuGroup = gtk_menu_new();
-	menuItem = gtk_menu_item_new_with_label (_("File"));
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuItem), menuGroup);
-	gtk_menu_append(menuBar, menuItem);
-	
-	menuItem = gtk_image_menu_item_new_with_label (_("Quit"));
-	image = gtk_image_new_from_stock (GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem), image);
-	g_signal_connect (G_OBJECT (menuItem), "activate", G_CALLBACK (on_menu_quit), (gpointer) uic);
-	gtk_menu_append(menuGroup, menuItem);
-	
-	menuGroup = gtk_menu_new();
-	menuItem = gtk_menu_item_new_with_label (_("Edit"));
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuItem), menuGroup);
-	gtk_menu_append(menuBar, menuItem);
-	
 	menuItem = gtk_check_menu_item_new_with_label (_("Transform + into 00"));
 	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_transform), (gpointer) uic);
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuItem), uic->transformPlus);
-	gtk_menu_append(menuGroup, menuItem);
+	gtk_menu_append(menuBar, menuItem);
+	
+	gtk_menu_append(menuBar, gtk_separator_menu_item_new());
 	
 	menuItem = gtk_check_menu_item_new_with_label (_("Notify me on incoming call"));
-	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_getCalls), (gpointer) uic);
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuItem), uic->getCalls);
-	gtk_menu_append(menuGroup, menuItem);
+	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_getCalls), (gpointer) uic);
+	gtk_menu_append(menuBar, menuItem);
 	
 	menuItem = gtk_check_menu_item_new_with_label (_("Notify me on SMS reception"));
-	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_getSms), (gpointer) uic);
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuItem), uic->getSms);
-	gtk_menu_append(menuGroup, menuItem);
-	
-	menuGroup = gtk_menu_new();
-	menuItem = gtk_menu_item_new_with_label (_("Help"));
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuItem), menuGroup);
+	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_getSms), (gpointer) uic);
 	gtk_menu_append(menuBar, menuItem);
 	
+	gtk_menu_append(menuBar, gtk_separator_menu_item_new());
+	
 	menuItem = gtk_image_menu_item_new_with_label (_("About ..."));
 	image = gtk_image_new_from_stock (GTK_STOCK_ABOUT, GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem), image);
 	g_signal_connect (G_OBJECT (menuItem), "activate", G_CALLBACK (on_menu_about), (gpointer) uic);
-	gtk_menu_append(menuGroup, menuItem);
+	gtk_menu_append(menuBar, menuItem);
+	
+	gtk_menu_append(menuBar, gtk_separator_menu_item_new());
+	
+	menuItem = gtk_image_menu_item_new_with_label (_("Quit"));
+	image = gtk_image_new_from_stock (GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem), image);
+	g_signal_connect (G_OBJECT (menuItem), "activate", G_CALLBACK (on_menu_quit), (gpointer) uic);
+	gtk_menu_append(menuBar, menuItem);
 	
 	return GTK_MENU(menuBar);
 }
@@ -1004,8 +1034,6 @@ int main( int argc, char *argv[] ) {
 	uic->getCalls= gconf_client_get_bool(gconf_client, GCONF_NOTIFY_CALL_KEY, NULL);
 	uic->getSms= gconf_client_get_bool(gconf_client, GCONF_NOTIFY_SMS_KEY, NULL);
 
-	hildon_window_set_menu (appview, create_menus (uic));
-
 /* Gnokii : read the config */
 	gn_error err;
 #ifdef GNOKII_GCONF
@@ -1051,6 +1079,9 @@ int main( int argc, char *argv[] ) {
 	g_signal_connect (G_OBJECT (appview), "delete_event",
 		      G_CALLBACK (delete_event), (gpointer) uic);
 
+	// Menus
+	hildon_window_set_menu (appview, create_menus (uic));
+
 	// la boite gnrale
 	table = gtk_table_new(9, 5, TRUE);
 	gtk_container_add (GTK_CONTAINER (appview), table);
@@ -1129,6 +1160,16 @@ int main( int argc, char *argv[] ) {
 	/* check availability and show or hide the Buttons */
 	g_idle_add ((GSourceFunc)checkAvailability_cb, uic);
 
+	if (uic->getSms) {
+		uic->getSms = FALSE;
+		getSms(GTK_WIDGET(appview), uic);
+	}
+	
+	if (uic->getCalls) {
+		uic->getCalls = FALSE;
+		getCalls(GTK_WIDGET(appview), uic);
+	}
+	
 	/* Rest in gtk_main and wait for the fun to begin! */
 	gtk_main ();
 
